@@ -1,14 +1,9 @@
 use swc_common::{Span, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::PatOrExprExt;
-use swc_ecma_transforms_base::perf::Check;
+use swc_ecma_transforms_base::{ext::PatOrExprExt, perf::Check};
 use swc_ecma_transforms_macros::fast_path;
-use swc_ecma_utils::member_expr;
-use swc_ecma_utils::private_ident;
-use swc_ecma_utils::ExprFactory;
-use swc_ecma_utils::StmtLike;
-use swc_ecma_visit::noop_visit_type;
-use swc_ecma_visit::{noop_fold_type, Fold, FoldWith, Node, Visit, VisitWith};
+use swc_ecma_utils::{member_expr, private_ident, ExprFactory, StmtLike};
+use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Node, Visit, VisitWith};
 
 /// `@babel/plugin-transform-exponentiation-operator`
 ///
@@ -193,8 +188,7 @@ impl Check for ShouldFold {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use swc_ecma_transforms_testing::test;
-    use swc_ecma_transforms_testing::test_exec;
+    use swc_ecma_transforms_testing::{test, test_exec};
 
     test!(
         ::swc_ecma_parser::Syntax::default(),
